# rainforest


[![Test rainforest master](https://github.com/MeteoSwiss/rainforest/actions/workflows/test_rainforest_master.yml/badge.svg?branch=master)](https://github.com/MeteoSwiss/rainforest/actions/workflows/test_rainforest_master.yml)
[![Test rainforest dev](https://github.com/MeteoSwiss/rainforest/actions/workflows/test_rainforest_dev.yml/badge.svg?branch=dev)](https://github.com/MeteoSwiss/rainforest/actions/workflows/test_rainforest_dev.yml)
[![build-deploy-site](https://github.com/MeteoSwiss/rainforest/actions/workflows/build_docs.yml/badge.svg)](https://github.com/MeteoSwiss/rainforest/actions/workflows/build_docs.yml)

A python library to access and update the gauge/station database of MDR and compute randomForest QPE estimates

Please see the [![Ref doc](https://img.shields.io/badge/docs-users-4088b8.svg)](https://meteoswiss.github.io/rainforest/) for further information

**Installation**

``` pip install rainforest-mch ```


Daniel Wolfensberger, Rebecca Gugerli, MeteoSwiss-MDRS - EPFL
February 2023
